summaryrefslogtreecommitdiff
path: root/interface/PluginInterface_PluginLoader.h
diff options
context:
space:
mode:
Diffstat (limited to 'interface/PluginInterface_PluginLoader.h')
-rw-r--r--interface/PluginInterface_PluginLoader.h35
1 files changed, 18 insertions, 17 deletions
diff --git a/interface/PluginInterface_PluginLoader.h b/interface/PluginInterface_PluginLoader.h
index 22f42ce..71d5935 100644
--- a/interface/PluginInterface_PluginLoader.h
+++ b/interface/PluginInterface_PluginLoader.h
@@ -1,8 +1,7 @@
/** \file PluginInterface_PluginLoader.h
\brief Define the interface of the plugin of type: plugin loader
\author alpha_one_x86
-\version 0.3
-\date 2010 */
+\licence GPL3, see the file COPYING */
#ifndef PLUGININTERFACE_PLUGINLOADER_H
#define PLUGININTERFACE_PLUGINLOADER_H
@@ -17,22 +16,24 @@
* */
class PluginInterface_PluginLoader : public QObject
{
- Q_OBJECT
- public:
- /// \brief try enable/disable the catching
- virtual void setEnabled(bool) = 0;
- /// \brief to set resources, writePath can be empty if read only mode
- virtual void setResources(OptionInterface * options,QString writePath,QString pluginPath,bool portableVersion) = 0;
- /// \brief to get the options widget, NULL if not have
- virtual QWidget * options() = 0;
- public slots:
- /// \brief to reload the translation, because the new language have been loaded
- virtual void newLanguageLoaded() = 0;
- /* signal to implement
- signals:
- void newState(CatchState);*/
+ Q_OBJECT
+ public:
+ /// \brief try enable/disable the catching
+ virtual void setEnabled(const bool &enabled) = 0;
+ /// \brief to set resources, writePath can be empty if read only mode
+ virtual void setResources(OptionInterface * options,const QString &writePath,const QString &pluginPath,const bool &portableVersion) = 0;
+ /// \brief to get the options widget, NULL if not have
+ virtual QWidget * options() = 0;
+ public slots:
+ /// \brief to reload the translation, because the new language have been loaded
+ virtual void newLanguageLoaded() = 0;
+ // signal to implement
+ signals:
+ void newState(const Ultracopier::CatchState &catchstate) const;
+ /// \brief To debug source
+ void debugInformation(const Ultracopier::DebugLevel &level,const QString &fonction,const QString &text,const QString &file,const int &ligne) const;
};
-Q_DECLARE_INTERFACE(PluginInterface_PluginLoader,"first-world.info.ultracopier.PluginInterface.PluginLoader/0.3.0.8");
+Q_DECLARE_INTERFACE(PluginInterface_PluginLoader,"first-world.info.ultracopier.PluginInterface.PluginLoader/1.0.0.0");
#endif // PLUGININTERFACE_PLUGINLOADER_H